@@ -38,13 +38,13 @@ class CaseImportChecker(BaseChecker):
             self.add_message(
                 "lower-case-function-import", node=node
             )
-        elif node.names[0][0] == "pyspark.sql.types" and node.names[0][1] == 't':
-            self.add_message(
-                "lower-case-type-import", node=node
-            )
+        # elif node.names[0][0] == "pyspark.sql.types" and node.names[0][1] == 't':
+        #     self.add_message(
+        #         "lower-case-type-import", node=node
+        #     )
 
     def visit_import(self, node):
-        self._check_import_stack.append(node)
+        self._check_import_stack.append([])
         self._check_import(node)
 
     def leave_import(self, node):
